@@ -1,6 +1,6 @@
 package Git::Repository::Command;
 {
-  $Git::Repository::Command::VERSION = '1.303';
+  $Git::Repository::Command::VERSION = '1.304';
 }
 
 use strict;
@@ -128,6 +128,17 @@ sub new {
             if defined $work_tree;
     }
 
+    # extract and process the 'fatal' option
+    push @o, {
+        fatal => {
+            128 => 1,    # fatal
+            129 => 1,    # usage
+            map s/^-// ? ( $_ => '' ) : ( $_ => 1 ),
+            map /^!0$/ ? ( 1 .. 255 ) : $_,
+            map ref() ? @$_ : $_, grep defined, map $_->{fatal}, @o
+        }
+    };
+
     # get and check the git command
     my $git_cmd = ( map { exists $_->{git} ? $_->{git} : () } @o )[-1];
 
@@ -163,9 +174,8 @@ sub final_output {
     # done with it
     $self->close;
 
-    # exit codes: 128 => fatal, 129 => usage
-    my $exit = $self->{exit};
-    if ( $exit == 128 || $exit == 129 ) {
+    # fatal exit codes set by the 'fatal' option
+    if ( $self->options->{fatal}{ $self->exit } ) {
         croak join( "\n", @errput ) || 'fatal: unknown git error';
     }
 
@@ -195,7 +205,7 @@ Git::Repository::Command - Command objects for running git
 
 =head1 VERSION
 
-version 1.303
+version 1.304
 
 =head1 SYNOPSIS
 
@@ -271,6 +281,23 @@ The I<current working directory> in which the git command will be run.
 
 A hashref containing key / values to add to the git command environment.
 
+=item C<fatal>
+
+An arrayref containing a list of exit codes that will be considered
+fatal by C<final_output()>.
+
+Prepending the value with C<-> will make it non-fatal, which can be
+useful to override a default. The string C<"!0"> can be used as a
+shortcut for C<[ 1 .. 255 ]>.
+
+If several option hashes have the C<fatal> key, the lists of exit codes
+will be combined, with the values provided last taking precedence (when
+using a combination of positive / negative values).
+
+The generated list always contains C<128> and C<129>; to make them
+non-fatal, just add C<-128> and C<-129> to the list provided to the
+C<fatal> option.
+
 =item C<input>
 
 A string that is send to the git command standard input, which is then closed.
@@ -324,8 +351,9 @@ successively to each line of output. The line being processed is in C<$_>,
 but the coderef must still return the result string.
 
 If the Git command printed anything on stderr, it will be printed as
-warnings. If the git sub-process exited with status C<128> (fatal error),
-or C<129> (usage message), it will C<die()>.
+warnings. If the git sub-process exited with a status code listed in
+the C<fatal> option, it will C<die()>. The defaults fatal exit codes
+are C<128> (fatal error), and C<129> (usage message).
 
 =head2 Accessors
 
